/*
 *  HID driver for some multilaser "special" devices
 *
 *  Copyright (c) 2008 Gustavo De Nardin <gustavodn@mandriva.com>
 *  Copyright (c) 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br>
 *
 *  Based on hid-dell/hid-bright drivers
 */

/*
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 */

#include <linux/device.h>
#include <linux/hid.h>
#include <linux/module.h>

#include "hid-ids.h"

static int multilaser_probe(struct hid_device *hdev, const struct hid_device_id *id)
{
	int ret;

	ret = hid_parse(hdev);
	if (ret) {
		dev_err(&hdev->dev, "parse failed\n");
		goto err_free;
	}

	ret = hid_hw_start(hdev, HID_CONNECT_DEFAULT);
	if (ret) {
		dev_err(&hdev->dev, "hw start failed\n");
		goto err_free;
	}

	usbhid_set_leds(hdev);

	return 0;
err_free:
	return ret;
}

static const struct hid_device_id multilaser_devices[] = {
	{ HID_USB_DEVICE(USB_VENDOR_ID_MULTILASER, USB_DEVICE_ID_MULTILASER_WI10046ML) },
	{ }
};
MODULE_DEVICE_TABLE(hid, multilaser_devices);

static struct hid_driver multilaser_driver = {
	.name = "multilaser",
	.id_table = multilaser_devices,
	.probe = multilaser_probe,
};

static int multilaser_init(void)
{
	return hid_register_driver(&multilaser_driver);
}

static void multilaser_exit(void)
{
	hid_unregister_driver(&multilaser_driver);
}

module_init(multilaser_init);
module_exit(multilaser_exit);
MODULE_LICENSE("GPL");
