
#include <linux/proc_fs.h>

static struct proc_dir_entry *foma_entry = NULL;
static struct uart_8250_port foma1_up;

static char *status_str[] = {
	"Wait",
	"Audio",
	"Packet",
	"Audio+Packet",
	"64K Data",
	"AV32K",
	"AV64K",
};

static int foma_proc_output(char *buffer)
{
	int bufpos=0;
	struct uart_8250_port * const pfoma1_up = &foma1_up;
	unsigned char data = serial_inp(pfoma1_up, UART_SCR);
	int level = data & 3;
	int fuzai = (data >> 2) & 1;
	int state = (data >> 3) & 7;
	bufpos += sprintf(buffer+bufpos, "___\n");
	bufpos += sprintf(buffer+bufpos, "\\|/    %c\n",
			level == 3 ? '|' : ' ');
	bufpos += sprintf(buffer+bufpos, " |   %c %c\n",
			level >= 2 ? '|' : ' ', level == 3 ? '|' : ' ');
	bufpos += sprintf(buffer+bufpos, " | %c %c %c\n",
			level >= 1 ? '|' : ' ', level >= 2 ? '|' : ' ', level == 3 ? '|' : ' ');

	bufpos += sprintf(buffer+bufpos, "level=%d\nfuzai=%d\nstate=%d %s\n", level, fuzai, state, status_str[state]);
	return bufpos;
}

static int foma_read_proc(char *page, char **start, off_t off,
			  int count, int *eof, void *data)
{
	int len = foma_proc_output (page);
	if (len <= off+count) *eof = 1;
	*start = page + off;
	len -= off;
	if (len>count) len = count;
	if (len<0) len = 0;
	return len;
}

static void foma_proc(struct uart_8250_port *up)
{
	if (foma_entry != NULL)
		return;
	foma_entry = create_proc_entry ("foma", 0, NULL);
	if (foma_entry != NULL){
		foma1_up.port.iobase = up->port.iobase;
		foma1_up.port.iotype = 0;
		foma_entry->read_proc = foma_read_proc;
	}
}

static void foma_proc_remove(struct uart_8250_port *up)
{
	if (foma_entry != NULL && foma1_up.port.iobase == up->port.iobase){
		remove_proc_entry ("foma", NULL);
		foma_entry = NULL;
	}
}

